@@ -1,21 +1,9 @@
-// SPDX-License-Identifier: GPL-3.0-or-later
 /*
-  Copyright 2017 - 2023 Martin Koller, kollix@aon.at
-
   This file is part of liquidshell.
 
-  liquidshell is free software: you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation, either version 3 of the License, or
-  (at your option) any later version.
+  SPDX-FileCopyrightText: 2017 - 2024 Martin Koller <kollix@aon.at>
 
-  liquidshell is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with liquidshell.  If not, see <http://www.gnu.org/licenses/>.
+  SPDX-License-Identifier: GPL-3.0-or-later
 */
 
 #include <Battery.hxx>
@@ -30,7 +18,6 @@
 
 #include <KLocalizedString>
 #include <KIconLoader>
-#include <kcmutils_version.h>
 
 #include <cmath>
 
@@ -200,19 +187,7 @@ QWidget *Battery::getDetailsList()
     dialog = new KCMultiDialog(this);
     dialog->setAttribute(Qt::WA_DeleteOnClose);
 
-    // different KDE versions need different ways ...
-    KPluginMetaData data("plasma/kcms/systemsettings_qwidgets/kcm_powerdevilglobalconfig");
-
-    if ( data.isValid() )
-    {
-      dialog->addModule(data);
-      dialog->addModule(KPluginMetaData("plasma/kcms/systemsettings_qwidgets/kcm_powerdevilprofilesconfig"));
-    }
-    else
-    {
-      dialog->addModule("powerdevilglobalconfig");
-      dialog->addModule("powerdevilprofilesconfig");
-    }
+    dialog->addModule(KPluginMetaData("plasma/kcms/systemsettings/kcm_powerdevilprofilesconfig"));
 
     dialog->adjustSize();
     dialog->setWindowTitle(i18n("Power Management"));
