@@ -1,21 +1,9 @@
-// SPDX-License-Identifier: GPL-3.0-or-later
 /*
-  Copyright 2017 - 2022 Martin Koller, kollix@aon.at
-
   This file is part of liquidshell.
 
-  liquidshell is free software: you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation, either version 3 of the License, or
-  (at your option) any later version.
+  SPDX-FileCopyrightText: 2017 - 2024 Martin Koller <kollix@aon.at>
 
-  liquidshell is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with liquidshell.  If not, see <http://www.gnu.org/licenses/>.
+  SPDX-License-Identifier: GPL-3.0-or-later
 */
 
 #include <NotificationServer.hxx>
@@ -29,6 +17,7 @@
 
 #include <KLocalizedString>
 #include <KService>
+#include <KIconLoader>
 
 //--------------------------------------------------------------------------------
 
@@ -55,6 +44,11 @@ NotificationServer::NotificationServer(QWidget *parent)
          );
 
   hide();
+
+  setAvoidPopup(getAvoidPopup());  // adjust icon for current state
+
+  connect(KIconLoader::global(), &KIconLoader::iconLoaderSettingsChanged, this,
+          [this]() { setAvoidPopup(getAvoidPopup()); });
 }
 
 //--------------------------------------------------------------------------------
@@ -121,7 +115,7 @@ uint NotificationServer::Notify(const QString &app_name, uint replaces_id, const
                                 const QVariantMap &hints, int timeout)
 {
   //qDebug() << "app" << app_name << "summary" << summary << "body" << theBody << "timeout" << timeout
-           //<< "replaceId" << replaces_id << "hints" << hints << "actions" << actions;
+           //<< "replaceId" << replaces_id << "hints" << hints << "actions" << actions << "app_icon" << app_icon;
 
   uint newId;
 
@@ -133,12 +127,20 @@ uint NotificationServer::Notify(const QString &app_name, uint replaces_id, const
   QString body(theBody);
   body.replace("\n", "<br>");
 
+  // icon preference order: https://specifications.freedesktop.org/notification-spec/latest/ar01s05.html
   QIcon icon;
-  if ( !app_icon.isEmpty() )
-    icon = QIcon::fromTheme(app_icon);
-  else if ( hints.contains("image-path") )
+  if ( hints.contains("image-data") )
+    icon = hints["image-data"].value<QIcon>();
+
+  if ( icon.isNull() && hints.contains("image-path") )
     icon = QIcon(hints["image-path"].toString());
 
+  if ( icon.isNull() && !app_icon.isEmpty() )
+    icon = QIcon::fromTheme(app_icon);
+
+  if ( icon.isNull() && hints.contains("icon_data") )
+    icon = hints["icon_data"].value<QIcon>();
+
   QString appName = app_name;
   if ( appName.isEmpty() && hints.contains("desktop-entry") )
   {
@@ -160,3 +162,22 @@ QWidget *NotificationServer::getDetailsList()
 }
 
 //--------------------------------------------------------------------------------
+
+void NotificationServer::setAvoidPopup(bool avoid)
+{
+  notificationList->setAvoidPopup(avoid);
+
+  if ( avoid )
+    setPixmap(QIcon::fromTheme(iconName).pixmap(size(), QIcon::Disabled));
+  else
+    setPixmap(QIcon::fromTheme(iconName).pixmap(size()));
+}
+
+//--------------------------------------------------------------------------------
+
+bool NotificationServer::getAvoidPopup() const
+{
+  return notificationList->getAvoidPopup();
+}
+
+//--------------------------------------------------------------------------------
