@@ -1,21 +1,9 @@
-// SPDX-License-Identifier: GPL-3.0-or-later
 /*
-  Copyright 2017 - 2023 Martin Koller, kollix@aon.at
-
   This file is part of liquidshell.
 
-  liquidshell is free software: you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation, either version 3 of the License, or
-  (at your option) any later version.
+  SPDX-FileCopyrightText: 2017 - 2024 Martin Koller <kollix@aon.at>
 
-  liquidshell is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with liquidshell.  If not, see <http://www.gnu.org/licenses/>.
+  SPDX-License-Identifier: GPL-3.0-or-later
 */
 
 #include <OnScreenVolume.hxx>
@@ -44,8 +32,8 @@ OnScreenVolume::OnScreenVolume(QWidget *parent)
   setFixedSize(400, 40);
   hide();
 
-  KWindowSystem::setState(winId(), NET::KeepAbove);
-  KWindowSystem::setType(winId(), NET::Dock);
+  KWinCompat::setState(winId(), NET::KeepAbove);
+  KWinCompat::setType(winId(), NET::Dock);
   KWinCompat::setOnAllDesktops(winId(), true);
 
   hideTimer.setInterval(1000);
@@ -120,10 +108,7 @@ void OnScreenVolume::gotMasterMixer(QDBusMessage msg)
   masterMixer = reply.value()["currentMasterMixer"].toString();
   masterMixer.replace(QRegularExpression("[^a-zA-Z0-9_]"), "_");
 
-  masterControl = reply.value()["currentMasterControl"].toString();
-  masterControl.replace(QRegularExpression("[^a-zA-Z0-9_]"), "_");
-
-  //qDebug() << masterMixer << masterControl;
+  //qDebug() << __FUNCTION__ << masterMixer;
 
   QDBusConnection::sessionBus()
       .connect("org.kde.kmix", "/Mixers/" + masterMixer,
@@ -132,9 +117,33 @@ void OnScreenVolume::gotMasterMixer(QDBusMessage msg)
 }
 
 //--------------------------------------------------------------------------------
+// called when e.g. volume changes but also if currentMasterControl changes
+// e.g. bluetooth headset connect/disconnect
 
 void OnScreenVolume::controlChanged()
 {
+  QDBusMessage msg =
+      QDBusMessage::createMethodCall("org.kde.kmix", "/Mixers",
+                                     "org.freedesktop.DBus.Properties",
+                                     "Get");
+
+  msg << "org.kde.KMix.MixSet" << "currentMasterControl";
+
+  QDBusConnection::sessionBus().callWithCallback(msg, this, SLOT(gotCurrentControl(QDBusMessage)));
+}
+
+//--------------------------------------------------------------------------------
+
+void OnScreenVolume::gotCurrentControl(QDBusMessage reply)
+{
+  if ( reply.type() == QDBusMessage::ErrorMessage )
+    return;
+
+  QString masterControl = reply.arguments()[0].value<QDBusVariant>().variant().toString();
+  masterControl.replace(QRegularExpression("[^a-zA-Z0-9_]"), "_");
+
+  //qDebug() << __FUNCTION__ << masterMixer << masterControl;
+
   QDBusMessage msg =
       QDBusMessage::createMethodCall("org.kde.kmix", "/Mixers/" + masterMixer + '/' + masterControl,
                                      "org.freedesktop.DBus.Properties",
