@@ -1,21 +1,9 @@
-// SPDX-License-Identifier: GPL-3.0-or-later
 /*
-  Copyright 2017 - 2023 Martin Koller, kollix@aon.at
-
   This file is part of liquidshell.
 
-  liquidshell is free software: you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation, either version 3 of the License, or
-  (at your option) any later version.
+  SPDX-FileCopyrightText: 2017 - 2024 Martin Koller <kollix@aon.at>
 
-  liquidshell is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with liquidshell.  If not, see <http://www.gnu.org/licenses/>.
+  SPDX-License-Identifier: GPL-3.0-or-later
 */
 
 #include <SysLoad.hxx>
@@ -26,13 +14,8 @@
 #include <QMouseEvent>
 #include <QDebug>
 
-#include <kio_version.h>
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
-#  include <KIO/CommandLauncherJob>
-#  include <KIO/JobUiDelegateFactory>
-#else
-#  include <KRun>
-#endif
+#include <KIO/CommandLauncherJob>
+#include <KIO/JobUiDelegateFactory>
 
 #include <KLocalizedString>
 
@@ -324,13 +307,9 @@ void SysLoad::mousePressEvent(QMouseEvent *event)
 {
   if ( event->button() == Qt::LeftButton )
   {
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
-    auto *job = new KIO::CommandLauncherJob("ksysguard");
+    KIO::CommandLauncherJob *job = new KIO::CommandLauncherJob("plasma-systemmonitor");
     job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
     job->start();
-#else
-    KRun::runCommand("ksysguard", this);
-#endif
   }
 }
 
